<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Duplicate</name>
    <message>
        <location filename="../DuplicateInit.js" line="+2"/>
        <source>&amp;Duplicate</source>
        <translation>&amp;Duplicare</translation>
    </message>
    <message>
        <source>1 entity duplicated</source>
        <translation type="vanished">Un entità è stato duplicato</translation>
    </message>
    <message>
        <source>%1 entities duplicated</source>
        <translation type="vanished">%1 entità sono stati duplicati</translation>
    </message>
    <message numerus="yes">
        <location filename="../Duplicate.js" line="+54"/>
        <source>%n entity/ies duplicated</source>
        <translation>
            <numerusform>Un entità è stato duplicato</numerusform>
            <numerusform>%n entità sono stati duplicati</numerusform>
        </translation>
    </message>
</context>
</TS>
